#!/usr/bin/env node
import path from "node:path";
import { fileURLToPath } from "node:url";
import {
  fs,
  gs,
  pico,
  envinfo,
  Command,
  prepareCli
} from "@mango-scripts/utils";
import changeExtname from "./scripts/changeExtname.mjs";
import addPackage from "./scripts/addPackage.mjs";
import gitGkd from "./scripts/gitGkd.mjs";
import releasePackage from "./scripts/releasePackage/index.mjs";
const packageJson = fs.readJSONSync(
  path.resolve(
    path.dirname(fileURLToPath(import.meta.url)),
    "../../package.json"
  )
);
const { name, version } = prepareCli(packageJson);
console.log(gs("@mango-scripts/dev-scripts\n"));
const program = new Command();
program.version(`${name} ${version}`).usage("<command> [options]");
program.command("releasePackage").description("\u5728Monorepo\u4ED3\u5E93\u6A21\u5F0F\u4E0B\uFF0C\u5FEB\u6377\u53D1\u5E03npm\u5305").allowUnknownOption().action(() => {
  releasePackage();
});
program.command("addPackage").description("\u5728Monorepo\u4ED3\u5E93\u6A21\u5F0F\u4E0B\uFF0C\u5FEB\u6377\u6DFB\u52A0\u5B50\u76EE\u5F55\u4F9D\u8D56\u5305").option(
  "-t, --targetDirList [dirPathList...]",
  "\u9700\u8981\u6DFB\u52A0\u4F9D\u8D56\u5305\u7684\u5B50\u76EE\u5F55\u5217\u8868",
  ["./apps", "./packages"]
).allowUnknownOption().action(() => {
  addPackage();
});
program.command("changeExtname").description("\u6279\u91CF\u8F6C\u6362\u6587\u4EF6\u540E\u7F00\u540D").option("-i, --input <dirPath>", "\u8F93\u5165\u76EE\u5F55\u8DEF\u5F84").option("-o, --output <dirPath>", "\u8F93\u51FA\u76EE\u5F55\u8DEF\u5F84").option("-r, --originExt <extName>", "\u539F\u59CB\u540E\u7F00\u540D\uFF0C\u4F8B\u5982 .js").option("-t, --targetExt <extName>", "\u76EE\u6807\u540E\u7F00\u540D\uFF0C\u4F8B\u5982 .ts").allowUnknownOption().action((options) => {
  changeExtname(options);
});
program.command("gitGkd").description("\u4E00\u952E\u5207\u6362\u3001\u5408\u5E76\u3001\u63A8\u9001\u76EE\u6807\u5206\u652F").option("-t, --targetBranch [branchName...]", "\u5207\u6362\u3001\u5408\u5E76\u3001\u63A8\u9001\u7684\u76EE\u6807\u5206\u652F", [
  "dev",
  "test"
]).allowUnknownOption().action((options) => {
  gitGkd(options);
});
program.command("info").description("\u6253\u5370\u8FD0\u884C\u73AF\u5883\u53C2\u6570").action(() => {
  console.log(pico.bold("\nEnvironment Info:"));
  envinfo.run(
    {
      System: ["OS", "CPU", "Memory", "Shell"],
      Binaries: ["Node", "Yarn", "npm"],
      Browsers: ["Chrome", "Edge", "Firefox", "Safari"]
    },
    {
      showNotFound: true,
      duplicates: true,
      fullTree: true
    }
  ).then(console.log);
});
program.on("command:*", ([cmd]) => {
  program.outputHelp();
  console.log(`  ` + pico.red(`Unknown command ${pico.yellow(cmd)}.
`));
  process.exitCode = 1;
});
program.on("--help", () => {
  console.log();
  console.log(
    `  Run ${pico.cyan(
      `${name} <command> --help`
    )} for detailed usage of given command.
`
  );
});
program.commands.forEach((c) => c.on("--help", () => console.log()));
program.parse(process.argv);
