import { fs, pico } from "@mango-scripts/utils";
import { run, step } from "../../utils/index.mjs";
const updateVersion = async (pkgPath, version) => {
  const pkg = await fs.readJSON(pkgPath);
  pkg.version = version;
  fs.writeFileSync(pkgPath, JSON.stringify(pkg, null, 2) + "\n");
};
const updateDepVersion = async (pkgPath, pkgList) => {
  const pkgJson = await fs.readJSON(pkgPath);
  const _updateVersion = (dependencies) => {
    if (!dependencies) return;
    for (const [key, value] of Object.entries(dependencies)) {
      if (value.startsWith("workspace:")) {
        const actualPkg = pkgList.find((pkg) => pkg.pkgName === key);
        if (actualPkg) {
          if (value === "workspace:*") {
            dependencies[key] = actualPkg.pkgCurrentVersion;
          } else if (value.startsWith("workspace:~")) {
            dependencies[key] = `~${actualPkg.pkgCurrentVersion}`;
          } else if (value.startsWith("workspace:^")) {
            dependencies[key] = `^${actualPkg.pkgCurrentVersion}`;
          } else if (value.startsWith("workspace:")) {
            dependencies[key] = value.replace("workspace:", "");
          }
          step(
            `\u66F4\u65B0\u4F9D\u8D56\u5305${pico.bgWhite(`[${key}:${value}]`)}\u5230${pico.bgWhite(`[${key}:${dependencies[key]}]`)}\u7248\u672C`
          );
        }
      }
    }
  };
  _updateVersion(pkgJson.dependencies);
  _updateVersion(pkgJson.devDependencies);
  _updateVersion(pkgJson.peerDependencies);
  fs.writeFile(pkgPath, JSON.stringify(pkgJson, null, 2) + "\n");
};
const updateChangelog = async (pkgDirPath, pkgName) => {
  await run(
    "npx",
    [
      "conventional-changelog",
      "-p",
      "conventionalcommits",
      "-i",
      "CHANGELOG.md",
      "-s",
      "--commit-path",
      ".",
      "--lerna-package",
      pkgName
    ],
    { cwd: pkgDirPath }
  );
};
export {
  updateChangelog,
  updateDepVersion,
  updateVersion
};
