import { semver, inquirer, consola, ora } from "@mango-scripts/utils";
import packageJson from "package-json";
const getVersionChoices = (pkgCurrentVersion) => {
  const currentBeta = pkgCurrentVersion.includes("beta");
  const currentAlpha = pkgCurrentVersion.includes("alpha");
  const isStable = !currentBeta && !currentAlpha;
  function inc(i, tag = currentAlpha ? "alpha" : "beta") {
    return semver.inc(pkgCurrentVersion, i, tag);
  }
  let versionChoices = [
    {
      name: "next",
      value: inc(isStable ? "patch" : "prerelease")
    }
  ];
  if (isStable) {
    versionChoices.push(
      {
        name: "beta-minor",
        value: inc("preminor")
      },
      {
        name: "beta-major",
        value: inc("premajor")
      },
      {
        name: "alpha-minor",
        value: inc("preminor", "alpha")
      },
      {
        name: "alpha-major",
        value: inc("premajor", "alpha")
      },
      {
        name: "minor",
        value: inc("minor")
      },
      {
        name: "major",
        value: inc("major")
      }
    );
  } else if (currentAlpha) {
    versionChoices.push({
      name: "beta",
      value: inc("patch") + "-beta.0"
    });
  } else {
    versionChoices.push({
      name: "stable",
      value: inc("patch")
    });
  }
  versionChoices.push({ value: "custom", name: "custom" });
  versionChoices = versionChoices.map((i) => {
    i.name = `${i.name} (${i.value})`;
    return i;
  });
  return versionChoices;
};
const setPkgTargetVersion = async (pkg) => {
  const { pkgName, pkgCurrentVersion } = pkg;
  let pkgTargetVersion;
  let remotePkgJson = void 0;
  const spinner = ora().start(`\u83B7\u53D6\u8FDC\u7A0Bnpm registry \u7248\u672C\u53F7...`);
  try {
    remotePkgJson = await packageJson(pkgName);
  } catch (error) {
  }
  spinner.stop();
  const { releaseType } = await inquirer.prompt([
    {
      type: "list",
      name: "releaseType",
      message: `\u9009\u62E9\u53D1\u5305\u7248\u672C ${remotePkgJson ? `[\u8FDC\u7A0Bnpm registry\u7248\u672C\u53F7: ${remotePkgJson.version}]` : `[\u8FDC\u7A0Bnpm registry \u6682\u65E0\u8BE5\u5305]`}`,
      choices: getVersionChoices(pkgCurrentVersion),
      loop: false
    }
  ]);
  if (releaseType === "custom") {
    const res = await inquirer.prompt([
      {
        type: "input",
        name: "version",
        message: "\u8F93\u5165\u81EA\u5B9A\u4E49\u7248\u672C\u53F7",
        default: pkgCurrentVersion
      }
    ]);
    pkgTargetVersion = res.version;
  } else {
    pkgTargetVersion = releaseType;
  }
  if (!semver.valid(pkgTargetVersion)) {
    consola.error(`\u4E0D\u5408\u6CD5\u7684\u7248\u672C\u53F7: ${pkgTargetVersion}\uFF0C\u8BF7\u68C0\u67E5`);
    return false;
  }
  if (remotePkgJson && semver.lt(pkgTargetVersion, remotePkgJson.version)) {
    consola.error(
      `\u672C\u5730\u7248\u672C\u53F7 ${pkgCurrentVersion} \u4F4E\u4E8E\u8FDC\u7A0B npm registry \u7248\u672C\u53F7 ${remotePkgJson.version}\uFF0C\u8BF7\u68C0\u67E5`
    );
    return false;
  }
  return pkgTargetVersion;
};
export {
  setPkgTargetVersion
};
